==> typegram-0.0.1-py3-none-any.whl: typegram/api/functions/account/sendChangePhoneCode.py <==

#===========================================================
#            Copyright (C) 2023-present AyiinXd
#===========================================================
#||                                                       ||
#||              _         _ _      __  __   _            ||
#||             /   _   _(_|_)_ __  / /__| |           ||
#||            / _ | | | | | | '_     _  | |           ||
#||           / ___  |_| | | | | | |/   (_| |           ||
#||          /_/   ___, |_|_|_| |_/_/___,_|           ||
#||                  |___/                                ||
#||                                                       ||
#===========================================================
# Appreciating the work of others is not detrimental to you
#===========================================================
#

from io import BytesIO
from typing import Any, Union, List, Optional

from typegram.api import ayiin, functions
from typegram.api.object import Object
from typegram.api.utils import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector



class SendChangePhoneCode(Object):  # type: ignore
    """Telegram API function.

    Details:
        - Layer: ``181``
        - ID: ``82574AE5``

phone_number (``str``):
                    N/A
                
        settings (:obj:`CodeSettings<typegram.api.ayiin.CodeSettings>`):
                    N/A
                
    Returns:
        :obj:`auth.SentCode<typegram.api.ayiin.auth.SentCode>`
    """

    __slots__: List[str] = ["phone_number", "settings"]

    ID = 0x82574ae5
    QUALNAME = "functions.functionsauth.SentCode"

    def __init__(self, *, phone_number: str, settings: "ayiin.CodeSettings") -> None:
        
                self.phone_number = phone_number  # string
        
                self.settings = settings  # CodeSettings

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "SendChangePhoneCode":
        # No flags
        
        phone_number = String.read(b)
        
        settings = Object.read(b)
        
        return SendChangePhoneCode(phone_number=phone_number, settings=settings)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(String(self.phone_number))
        
        b.write(self.settings.write())
        
        return b.getvalue()

==> typegram-0.0.2-py3-none-any.whl: typegram/api/functions/account/sendChangePhoneCode.py <==

#===========================================================
#            Copyright (C) 2023-present AyiinXd
#===========================================================
#||                                                       ||
#||              _         _ _      __  __   _            ||
#||             /   _   _(_|_)_ __  / /__| |           ||
#||            / _ | | | | | | '_     _  | |           ||
#||           / ___  |_| | | | | | |/   (_| |           ||
#||          /_/   ___, |_|_|_| |_/_/___,_|           ||
#||                  |___/                                ||
#||                                                       ||
#===========================================================
# Appreciating the work of others is not detrimental to you
#===========================================================
#

from io import BytesIO
from typing import Any, Union, List, Optional

from typegram import api
from typegram.api.object import Object
from typegram.api.utils import Int, Long, Int128, Int256, Bool, Bytes, String, Double, Vector



class SendChangePhoneCode(Object):  # type: ignore
    """Telegram API function.

    Details:
        - Layer: ``181``
        - ID: ``82574AE5``

phone_number (``str``):
                    N/A
                
        settings (:obj:`CodeSettings<typegram.api.ayiin.CodeSettings>`):
                    N/A
                
    Returns:
        :obj:`auth.SentCode<typegram.api.ayiin.auth.SentCode>`
    """

    __slots__: List[str] = ["phone_number", "settings"]

    ID = 0x82574ae5
    QUALNAME = "functions.account.sendChangePhoneCode"

    def __init__(self, *, phone_number: str, settings: "api.ayiin.CodeSettings") -> None:
        
                self.phone_number = phone_number  # string
        
                self.settings = settings  # CodeSettings

    @staticmethod
    def read(b: BytesIO, *args: Any) -> "SendChangePhoneCode":
        # No flags
        
        phone_number = String.read(b)
        
        settings = Object.read(b)
        
        return SendChangePhoneCode(phone_number=phone_number, settings=settings)

    def write(self, *args) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(String(self.phone_number))
        
        b.write(self.settings.write())
        
        return b.getvalue()
